pub struct Mapping {
pub phys_base: u64,
pub virt_base: u64,
pub len: u64,
pub kind: MappingKind,
pub user_accessible: bool,
}Fields
phys_base: u64virt_base: u64len: u64kind: MappingKinduser_accessible: boolOn architectures that support multiple privilege levels inside the guest, whether the mapping is accessible to the lower-privileged level (with the same permissions/behaviour as the upper-privileged level, for now).